@@ -1,12 +1,13 @@
-#' @importFrom dplyr filter select %>% full_join mutate bind_rows case_when
+#' @importFrom dplyr filter select %>% full_join mutate bind_rows case_when vars
 #' @importFrom dplyr one_of ungroup slice bind_cols pull sample_n desc anti_join
 #' @importFrom dplyr distinct arrange rename mutate_if starts_with inner_join
+#' @importFrom dplyr last
 #' @importFrom tibble tibble lst is_tibble as_tibble
 #' @importFrom rlang call2 ns_env is_quosure is_quosures quo_get_expr call_name
 #' @importFrom rlang is_false eval_tidy expr sym syms env_get is_function :=
-#' @importFrom rlang is_missing
+#' @importFrom rlang is_missing %||%
 #' @importFrom glue glue glue_collapse
-#' @importFrom utils globalVariables capture.output packageVersion
+#' @importFrom utils globalVariables capture.output packageVersion object.size
 #' @importFrom dials parameters_constr is_unknown encode_unit
 #' @importFrom stats sd qt qnorm dnorm pnorm predict model.matrix setNames
 #' @importFrom stats model.matrix model.response model.frame update
@@ -16,7 +17,7 @@
 #' @importFrom parsnip get_from_env
 #' @importFrom recipes all_predictors all_outcomes
 #' @importFrom ggplot2 ggplot aes xlab geom_point geom_errorbar facet_wrap ylab
-#' @importFrom ggplot2 facet_grid
+#' @importFrom ggplot2 facet_grid geom_line aes_string aes_
 #' @importFrom cli cli_alert_danger cli_alert_info cli_alert_warning
 #' @importFrom cli cli_alert_success cli_alert
 #' @importFrom foreach foreach getDoParName
@@ -42,12 +43,13 @@ ggplot2::autoplot
 utils::globalVariables(
   c("engine", "name", "func", "parsnip", "call_name", ".step", "call_info",
     "component", "component_id", "id", "control", ".pred", ".metric",
-    ".estimator", ".estimate", "n", "object", "splits", "grid", "resamples",
-    ".iter", "mean", ".submodels", "metrics", "data", ".mean", ".sd",
-    "rs_iter", "pkg", ".pred_class", "std_err", "const", "objective", "delta",
-    "sd_trunc", "snr", "z", "..val", "max_val", "has_submodel", "res",
+    ".estimator", ".estimate", "n", "note", "object", "splits", "grid",
+    "resamples", ".iter", "mean", ".submodels", "metrics", "data", ".mean",
+    ".sd", "rs_iter", "pkg", ".pred_class", "std_err", "const", "objective",
+    "delta", "sd_trunc", "snr", "z", "..val", "max_val", "has_submodel", "res",
     ".extracts", ".metrics", "value", ".notes", ".loss", ".bound",
-    ".column", ".totals", ".value", "direction")
+    ".column", ".totals", ".value", "direction", ".config", "Freq", "Prediction",
+    "Truth")
   )
 
 # ------------------------------------------------------------------------------
