@@ -181,7 +181,7 @@ prob_summarize <- function(x, p) {
   }
 
   nms <- names(x)
-  y_cols <- nms[!(nms %in% c(".row", ".iter", pred_cols, p))]
+  y_cols <- nms[!(nms %in% c(".row", ".iter", ".config", pred_cols, p))]
   group_cols <- nms[!(nms %in% pred_cols)]
 
   x <-
@@ -230,7 +230,7 @@ prob_summarize <- function(x, p) {
       dplyr::mutate(
         .pred_class = gsub("\\.pred_", "", .column),
         .pred_class = factor(.pred_class, levels = lvl, ordered = ord)
-        ) %>%
+      ) %>%
       dplyr::ungroup() %>%
       dplyr::select(-.value, -.column)
     x <- full_join(x, class_pred, by = group_cols)
@@ -242,7 +242,7 @@ class_summarize <- function(x, p) {
   pred_cols <- grep("^\\.pred", names(x), value = TRUE)
   nms <- names(x)
   group_cols <- nms[!(nms %in% pred_cols)]
-  outcome_col <- group_cols[!(group_cols %in% c(p, ".row", ".iter"))]
+  outcome_col <- group_cols[!(group_cols %in% c(p, ".row", ".iter", ".config"))]
   x <-
     x %>%
     dplyr::group_by(!!!rlang::syms(group_cols)) %>%
@@ -284,6 +284,9 @@ average_predictions <- function(x, grid = NULL) {
     x <- class_summarize(x, param_names)
   }
 
+  if (dplyr::is_grouped_df(x)) {
+    x <- dplyr::ungroup(x)
+  }
   x
 }
 
@@ -326,10 +329,15 @@ collector <- function(x, coll_col = ".predictions") {
   x
 }
 
+#' @export
+#' @keywords internal
+#' @rdname empty_ellipses
 estimate_tune_results <- function(x, ...) {
+  param_names <- .get_tune_parameter_names(x)
+
   all_bad <- is_cataclysmic(x)
   if (all_bad) {
-    stop("All of the models failed.", call. = FALSE)
+    rlang::abort("All of the models failed. See the .notes column.")
   }
 
   tibble_metrics <- purrr::map_lgl(x$.metrics, tibble::is_tibble)
@@ -341,11 +349,12 @@ estimate_tune_results <- function(x, ...) {
     keep_cols <- ".metrics"
   }
   x <- tidyr::unnest(x, cols = dplyr::one_of(keep_cols))
+
   all_col <- names(x)
   excl_cols <- c(".metric", ".estimator", ".estimate", "splits", ".notes",
                  grep("^id", all_col, value = TRUE), ".predictions", ".extracts")
   param_names <- all_col[!(all_col %in% excl_cols)]
-  x %>%
+  x <- x %>%
     tibble::as_tibble() %>%
     dplyr::group_by(!!!rlang::syms(param_names), .metric, .estimator) %>%
     dplyr::summarize(
@@ -354,5 +363,16 @@ estimate_tune_results <- function(x, ...) {
       std_err = sd(.estimate, na.rm = TRUE)/sqrt(n)
     ) %>%
     dplyr::ungroup()
+
+  if (".config" %in% param_names) {
+    join_names <- param_names[!(param_names %in% ".config")]
+    x <- dplyr::inner_join(
+      dplyr::select(x, -.config),
+      x,
+      by = c(join_names, ".metric", ".estimator", "mean", "n", "std_err")
+    ) %>%
+      dplyr::arrange(.config)
+  }
+  x
 }
 
